@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless;
-$Footprintless::VERSION = '1.17';
+$Footprintless::VERSION = '1.18';
 # ABSTRACT: A utility for managing systems with minimal installs
 # PODNAME: Footprintless
 
@@ -28,7 +28,7 @@ sub AUTOLOAD {
     my ( $self, @args ) = @_;
     my $method = $AUTOLOAD;
     $method =~ s/.*:://;
-    $self->{factory}->$method(@args);
+    $self->{factory}->$method(@args) if ( $self->{factory} );
 }
 
 sub command_options_factory {
@@ -189,7 +189,7 @@ Footprintless - A utility for managing systems with minimal installs
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 SYNOPSIS
 
