@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::ActionCommand;
-$Footprintless::App::ActionCommand::VERSION = '1.17';
+$Footprintless::App::ActionCommand::VERSION = '1.18';
 # ABSTRACT: A base class for action commands
 # PODNAME: Footprintless::App::ActionCommand
 
@@ -73,7 +73,7 @@ sub prepare {
     my ( $opts, $remaining_args, %fields ) =
         $class->_process_args( \@args, $class->usage_desc(), $class->opt_spec() );
 
-    my ( $coordinate, $action_name, my @action_args ) = @$remaining_args;
+    my ( $coordinate, $action_name, @action_args ) = @$remaining_args;
     $fields{coordinate} = $coordinate;
 
     if ($action_name) {
@@ -138,7 +138,7 @@ Footprintless::App::ActionCommand - A base class for action commands
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 AUTHOR
 
