@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.17';
+$Footprintless::Util::VERSION = '1.18';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -232,9 +232,8 @@ sub spurt {
 
 sub temp_dir {
     require File::Temp;
-    File::Temp->safe_level( File::Temp::HIGH() );
     my $temp = File::Temp->newdir( 'fpl_XXXXXXXX', TMPDIR => 1 );
-    if ( !chmod( 0700, $temp ) ) {
+    if ( !chmod( 02700, $temp ) ) {
         croak("unable to create secure temp file");
     }
     return $temp;
@@ -243,7 +242,6 @@ sub temp_dir {
 sub temp_file {
     my (%options) = @_;
     require File::Temp;
-    File::Temp->safe_level( File::Temp::HIGH() );
     my $temp = File::Temp->new(
         'fpl_XXXXXXXX',
         TMPDIR => 1,
@@ -267,7 +265,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 SYNOPSIS
 
@@ -401,13 +399,15 @@ Writes C<$content> to C<$file>.  The available options are:
 
 =head2 temp_file()
 
-Creates a new temporary file with C<safe_level> set to 
-C<HIGH>.  Returns the new L<File::Temp> object.
+Creates a new temporary file with mode C<0600>
+Returns the new L<File::Temp> object.  Uses C<File::Temp> so you can set
+C<File::Temp::HIGH> for extra safety.
 
 =head2 temp_dir()
 
-Creates a new temporary directory with C<safe_level> set to 
-C<HIGH>.  Returns the new L<File::Temp> object.
+Creates a new temporary directory with mode C<2700>.
+Returns the new L<File::Temp> object.  Uses C<File::Temp> so you can set
+C<File::Temp::HIGH> for extra safety.
 
 =over 4
 
